@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.core._jsii
@@ -15,9 +15,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-globalaccelerator",
-    "1.59.0",
+    "1.66.0",
     __name__[0:-6],
-    "aws-globalaccelerator@1.59.0.jsii.tgz",
+    "aws-globalaccelerator@1.66.0.jsii.tgz",
 )
 
 __all__ = [
